@@ -12,12 +12,10 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.utils.translation import ugettext_lazy as _
-
+from django.utils.translation import gettext_lazy as _
 from horizon import exceptions
 from horizon import forms
 from horizon import workflows
-
 from openstack_dashboard import api
 
 from neutron_vpnaas_dashboard.api import vpn as api_vpn
